@@ -1122,6 +1122,40 @@ opposite_edges_around_face(typename boost::graph_traits<Graph>::halfedge_descrip
   return make_range(I(h,g), I(h,g,1));
 }
 
+template <typename Graph>
+class Edge_around_face_iterator
+#ifndef DOXYGEN_RUNNING
+  : public boost::iterator_adaptor<
+            Edge_around_face_iterator<Graph>                       // Derived
+             , Halfedge_around_face_iterator<Graph>                // Base
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Value
+             , std::bidirectional_iterator_tag                       // CategoryOrTraversal
+             , typename boost::graph_traits<Graph>::edge_descriptor  // Reference
+             >
+#endif
+{
+  typedef typename boost::graph_traits<Graph>::halfedge_descriptor halfedge_descriptor;
+  internal::Edge<Graph> fct;
+public:
+
+  Edge_around_face_iterator()
+  {}
+
+  Edge_around_face_iterator(halfedge_descriptor h, const Graph& g, int n = 0)
+    : Edge_around_face_iterator::iterator_adaptor_(Halfedge_around_face_iterator<Graph>(h,g,(h==halfedge_descriptor())?1:n)), fct(g)
+  {}
+private:
+  friend class boost::iterator_core_access;
+  typename  boost::graph_traits<Graph>::edge_descriptor dereference() const { return fct(*this->base_reference()); }
+}; 
+
+template<typename Graph>
+Iterator_range<Edge_around_face_iterator<Graph> >
+edges_around_face(typename boost::graph_traits<Graph>::halfedge_descriptor h, const Graph& g)
+{
+  typedef Edge_around_face_iterator<Graph> I;
+  return make_range(I(h,g), I(h,g,1));
+}
 
 
 
